==> owncloud-10.2.0.zip: owncloud/apps/files_sharing/l10n/da.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server til serverdeling er ikke slået til på denne server",
    "The mountpoint name contains invalid characters." : "Monteringspunktets navn indeholder ugyldige tegn.",
    "Not allowed to create a federated share with the same user server" : "Det er ikke tilladt at danne et datafællesskab med samme brugerserver",
    "Invalid or untrusted SSL certificate" : "Ugyldigt eller upålideligt SSL-certifikat",
    "Could not authenticate to remote share, password might be wrong" : "Kunne ikke godkende fjerndelingen - kodeordet er muilgvis forkert",
    "Storage not valid" : "Lagerplads er ikke gyldig",
    "Couldn't add remote share" : "Kunne ikke tliføje den ekstern deling",
    "Shared with you" : "Delt med dig",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt via link",
    "Uploading..." : "Uploader...",
    "Nothing shared with you yet" : "Der deles ikke noget med dig endnu",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med dig, vil blive vist her",
    "Nothing shared yet" : "Der deles endnu ikke noget",
    "Files and folders you share will show up here" : "Filer og mapper som du deler, vil blive vist her",
    "No shared links" : "Ingen delte link",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler gennem link, vil blive vist her",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vil du tilføje den eksterne deling {name} fra {owner}@{remote}?",
    "Remote share" : "Ekstern deling",
    "Remote share password" : "Adgangskode for ekstern deling",
    "Cancel" : "Annuller",
    "Add remote share" : "Tilføj ekstern deling",
    "You can upload into this folder" : "Du kan overføre til denne mappe",
    "No ownCloud installation (7 or higher) found at {remote}" : "Der er ingen ownCloud-installation (7 eller højere) på {remote}",
    "Invalid ownCloud url" : "Ugyldig ownCloud-URL",
    "Share" : "Del",
    "No expiration date set" : "Der er ikke sat nogen udløbsdato",
    "Shared by" : "Delt af",
    "Sharing" : "Deling",
    "Share API is disabled" : "Delt API er deaktiveret",
    "Wrong share ID, share doesn't exist" : "Forkert dele-ID, delen eksisterer ikke",
    "Could not delete share" : "Kunne ikke slette delen",
    "Please specify a file or folder path" : "Angiv en fil eller mappe sti",
    "Wrong path, file/folder doesn't exist" : "Forkert sti; fil/mappe eksisterer ikke",
    "Please specify a valid user" : "Angiv en gyldig bruger",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktiveret af administratoren",
    "Please specify a valid group" : "Angiv venligst en gyldig gruppe",
    "Public link sharing is disabled by the administrator" : "Offentlig link deling er deaktiveret af administratoren",
    "Public upload disabled by the administrator" : "Offentlige indlæg er deaktiveret af administratoren",
    "Public upload is only possible for publicly shared folders" : "Offentlige indlæg er kun muligt for offentligt delte mapper",
    "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato; datoformatet skal være ÅÅÅÅ-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delingen %s mislykkedes; fordi systemindgangen ikke tillader delinger af typen %s",
    "Unknown share type" : "Ukendt delingstype",
    "Not a directory" : "Er ikke en mappe",
    "Could not lock path" : "Kunne ikke låse stien",
    "Can't change permissions for public share links" : "Kan ikke ændre tilladelser for offentlige delelinks",
    "Wrong or no update parameter given" : "Forkert eller ingen opdateringsparameter givet",
    "Cannot increase permissions" : "Kan ikke forhøje tilladelser",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe er blevet <strong>delt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe blev delt fra <strong>en anden server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En offentligt delt fil eller mappe blev <strong>hentet</strong>",
    "You received a new remote share %2$s from %1$s" : "Du modtog en ny ekstern deling %2$s fra %1$s",
    "You received a new remote share from %s" : "Du modtog en ny ekstern deling fra %s",
    "%1$s accepted remote share %2$s" : "%1$s accepterede den ekstern deling %2$s",
    "%1$s declined remote share %2$s" : "%1$s afviste den eksterne deling %2$s",
    "%1$s unshared %2$s from you" : "%1$s stoppede med at dele %2$s med dig",
    "Public shared folder %1$s was downloaded" : "Den offentligt delte mappe %1$s blev downloadet",
    "Public shared file %1$s was downloaded" : "Den offentligt delte fil %1$s blev downloadet",
    "You shared %1$s with %2$s" : "Du delte %1$s med %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s delt %1$s med %3$s",
    "You removed the share of %2$s for %1$s" : "Du fjernede delingen af %2$s for %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s fjernede delingen af %3$s for %1$s",
    "You shared %1$s with group %2$s" : "Du delte %1$s med gruppen %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s delt %1$s med gruppen %3$s",
    "You removed the share of group %2$s for %1$s" : "Du fjernede delingen af gruppe %2$s for %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s fjernede delingen af gruppe %3$s for %1$s",
    "%2$s shared %1$s via link" : "%2$s delt %1$s via link",
    "You shared %1$s via link" : "Du delte %1$s via link",
    "You removed the public link for %1$s" : "Du fjernede det offentlige link for %1$s",
    "%2$s removed the public link for %1$s" : "%2$s fjernede det offentlige link for %1$s",
    "Your public link for %1$s expired" : "Dit offentlige link for %1$s udløb",
    "The public link of %2$s for %1$s expired" : "Det offentlige link af %2$s for %1$s udløb",
    "%2$s shared %1$s with you" : "%2$s delt %1$s med dig",
    "%2$s removed the share for %1$s" : "%2$s fjernede delingen for %1$s",
    "Downloaded via public link" : "Downloaded via et offentligt link",
    "Shared with %2$s" : "Delt med %2$s",
    "Shared with %3$s by %2$s" : "Delt med %3$s af %2$s",
    "Removed share for %2$s" : "Fjernede delingen for %2$s",
    "%2$s removed share for %3$s" : "%2$s fjernede delingen for %3$s",
    "Shared with group %2$s" : "Delt med gruppen %2$s",
    "Shared with group %3$s by %2$s" : "Delt med gruppen %3$s af %2$s",
    "Removed share of group %2$s" : "Fjernede delingen af gruppe %2$s",
    "%2$s removed share of group %3$s" : "%2$s Fjernede delingen af gruppe %3$s",
    "Shared via link by %2$s" : "Delt via link af %2$s",
    "Shared via public link" : "Delt via offentligt link",
    "Removed public link" : "Fjernede offentligt link",
    "%2$s removed public link" : "%2$s fjernede offentligt link",
    "Public link expired" : "Offentligt link er udløbet",
    "Public link of %2$s expired" : "Offentligt link af %2$s er udløbet",
    "Shared by %2$s" : "Delt af %2$s",
    "Shares" : "Delt",
    "This share is password-protected" : "Delingen er beskyttet af kodeord",
    "The password is wrong. Try again." : "Kodeordet er forkert. Prøv igen.",
    "Password" : "Kodeord",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Name" : "Navn",
    "Share time" : "Dele periode",
    "Expiration date" : "Udløbsdato",
    "Sorry, this link doesn’t seem to work anymore." : "Desværre, dette link ser ikke ud til at fungerer længere.",
    "Reasons might be:" : "Årsagen kan være:",
    "the item was removed" : "Filen blev fjernet",
    "the link expired" : "linket udløb",
    "sharing is disabled" : "deling er deaktiveret",
    "For more info, please ask the person who sent this link." : "For yderligere information, kontakt venligst personen der sendte linket. ",
    "%s is publicly shared" : "%s er offentlig delt",
    "Add to your ownCloud" : "Tilføj til din ownCload",
    "Download" : "Hent",
    "Download %s" : "Hent %s",
    "Direct link" : "Direkte link",
    "Anonymous upload" : "Anonym upload",
    "Uploaded files" : "Uploadede filer",
    "Click to select files or use drag & drop to upload" : "Tryk for at vælge filer eller brug drag & drop til at uploade",
    "Cannot remove all permissions" : "Can ikke fjerne alle tilladelser",
    "Pending" : "Afventer",
    "Accept" : "Acceptér",
    "Decline" : "Afvis",
    "Declined" : "Afvist"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files_sharing/l10n/da.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server til serverdeling er ikke slået til på denne server",
    "The mountpoint name contains invalid characters." : "Monteringspunktets navn indeholder ugyldige tegn.",
    "Not allowed to create a federated share with the same user server" : "Det er ikke tilladt at danne et datafællesskab med samme brugerserver",
    "Invalid or untrusted SSL certificate" : "Ugyldigt eller upålideligt SSL-certifikat",
    "Could not authenticate to remote share, password might be wrong" : "Kunne ikke godkende fjerndelingen - kodeordet er muilgvis forkert",
    "Storage not valid" : "Lagerplads er ikke gyldig",
    "Couldn't add remote share" : "Kunne ikke tliføje den ekstern deling",
    "Shared with you" : "Delt med dig",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt via link",
    "Anonymous upload" : "Anonym upload",
    "Click to select files or use drag & drop to upload" : "Tryk for at vælge filer eller brug drag & drop til at uploade",
    "Uploaded files" : "Uploadede filer",
    "Uploading..." : "Uploader...",
    "Nothing shared with you yet" : "Der deles ikke noget med dig endnu",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med dig, vil blive vist her",
    "Nothing shared yet" : "Der deles endnu ikke noget",
    "Files and folders you share will show up here" : "Filer og mapper som du deler, vil blive vist her",
    "No shared links" : "Ingen delte link",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler gennem link, vil blive vist her",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vil du tilføje den eksterne deling {name} fra {owner}@{remote}?",
    "Remote share" : "Ekstern deling",
    "Remote share password" : "Adgangskode for ekstern deling",
    "Cancel" : "Annuller",
    "Add remote share" : "Tilføj ekstern deling",
    "You can upload into this folder" : "Du kan overføre til denne mappe",
    "No ownCloud installation (7 or higher) found at {remote}" : "Der er ingen ownCloud-installation (7 eller højere) på {remote}",
    "Invalid ownCloud url" : "Ugyldig ownCloud-URL",
    "Share" : "Del",
    "No expiration date set" : "Der er ikke sat nogen udløbsdato",
    "Declined" : "Afvist",
    "Pending" : "Afventer",
    "Shared by" : "Delt af",
    "Sharing" : "Deling",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe er blevet <strong>delt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe blev delt fra <strong>en anden server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En offentligt delt fil eller mappe blev <strong>hentet</strong>",
    "You received a new remote share %2$s from %1$s" : "Du modtog en ny ekstern deling %2$s fra %1$s",
    "You received a new remote share from %s" : "Du modtog en ny ekstern deling fra %s",
    "%1$s accepted remote share %2$s" : "%1$s accepterede den ekstern deling %2$s",
    "%1$s declined remote share %2$s" : "%1$s afviste den eksterne deling %2$s",
    "%1$s unshared %2$s from you" : "%1$s stoppede med at dele %2$s med dig",
    "Public shared folder %1$s was downloaded" : "Den offentligt delte mappe %1$s blev downloadet",
    "Public shared file %1$s was downloaded" : "Den offentligt delte fil %1$s blev downloadet",
    "You shared %1$s with %2$s" : "Du delte %1$s med %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s delt %1$s med %3$s",
    "You removed the share of %2$s for %1$s" : "Du fjernede delingen af %2$s for %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s fjernede delingen af %3$s for %1$s",
    "You shared %1$s with group %2$s" : "Du delte %1$s med gruppen %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s delt %1$s med gruppen %3$s",
    "You removed the share of group %2$s for %1$s" : "Du fjernede delingen af gruppe %2$s for %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s fjernede delingen af gruppe %3$s for %1$s",
    "%2$s shared %1$s via link" : "%2$s delt %1$s via link",
    "You shared %1$s via link" : "Du delte %1$s via link",
    "You removed the public link for %1$s" : "Du fjernede det offentlige link for %1$s",
    "%2$s removed the public link for %1$s" : "%2$s fjernede det offentlige link for %1$s",
    "Your public link for %1$s expired" : "Dit offentlige link for %1$s udløb",
    "The public link of %2$s for %1$s expired" : "Det offentlige link af %2$s for %1$s udløb",
    "%2$s shared %1$s with you" : "%2$s delt %1$s med dig",
    "%2$s removed the share for %1$s" : "%2$s fjernede delingen for %1$s",
    "Downloaded via public link" : "Downloaded via et offentligt link",
    "Shared with %2$s" : "Delt med %2$s",
    "Shared with %3$s by %2$s" : "Delt med %3$s af %2$s",
    "Removed share for %2$s" : "Fjernede delingen for %2$s",
    "%2$s removed share for %3$s" : "%2$s fjernede delingen for %3$s",
    "Shared with group %2$s" : "Delt med gruppen %2$s",
    "Shared with group %3$s by %2$s" : "Delt med gruppen %3$s af %2$s",
    "Removed share of group %2$s" : "Fjernede delingen af gruppe %2$s",
    "%2$s removed share of group %3$s" : "%2$s Fjernede delingen af gruppe %3$s",
    "Shared via link by %2$s" : "Delt via link af %2$s",
    "Shared via public link" : "Delt via offentligt link",
    "Removed public link" : "Fjernede offentligt link",
    "%2$s removed public link" : "%2$s fjernede offentligt link",
    "Public link expired" : "Offentligt link er udløbet",
    "Public link of %2$s expired" : "Offentligt link af %2$s er udløbet",
    "Shared by %2$s" : "Delt af %2$s",
    "Shares" : "Delt",
    "Share API is disabled" : "Delt API er deaktiveret",
    "Wrong share ID, share doesn't exist" : "Forkert dele-ID, delen eksisterer ikke",
    "Could not delete share" : "Kunne ikke slette delen",
    "Please specify a file or folder path" : "Angiv en fil eller mappe sti",
    "Wrong path, file/folder doesn't exist" : "Forkert sti; fil/mappe eksisterer ikke",
    "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato; datoformatet skal være ÅÅÅÅ-MM-DD",
    "Please specify a valid user" : "Angiv en gyldig bruger",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktiveret af administratoren",
    "Please specify a valid group" : "Angiv venligst en gyldig gruppe",
    "Public link sharing is disabled by the administrator" : "Offentlig link deling er deaktiveret af administratoren",
    "Public upload disabled by the administrator" : "Offentlige indlæg er deaktiveret af administratoren",
    "Public upload is only possible for publicly shared folders" : "Offentlige indlæg er kun muligt for offentligt delte mapper",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delingen %s mislykkedes; fordi systemindgangen ikke tillader delinger af typen %s",
    "Unknown share type" : "Ukendt delingstype",
    "Not a directory" : "Er ikke en mappe",
    "Could not lock path" : "Kunne ikke låse stien",
    "Can't change permissions for public share links" : "Kan ikke ændre tilladelser for offentlige delelinks",
    "Accept" : "Acceptér",
    "Decline" : "Afvis",
    "This share is password-protected" : "Delingen er beskyttet af kodeord",
    "The password is wrong. Try again." : "Kodeordet er forkert. Prøv igen.",
    "Password" : "Kodeord",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Name" : "Navn",
    "Share time" : "Dele periode",
    "Expiration date" : "Udløbsdato",
    "Sorry, this link doesn’t seem to work anymore." : "Desværre, dette link ser ikke ud til at fungerer længere.",
    "Reasons might be:" : "Årsagen kan være:",
    "the item was removed" : "Filen blev fjernet",
    "the link expired" : "linket udløb",
    "sharing is disabled" : "deling er deaktiveret",
    "For more info, please ask the person who sent this link." : "For yderligere information, kontakt venligst personen der sendte linket. ",
    "%s is publicly shared" : "%s er offentlig delt",
    "Download" : "Hent",
    "Download %s" : "Hent %s",
    "Direct link" : "Direkte link"
},
"nplurals=2; plural=(n != 1);");
